@@ -1,5 +1,6 @@
 from porerefiner.app import app
-from porerefiner.cli_utils import server, load_from_csv
+from porerefiner.cli_utils import server
+from porerefiner.samplesheets import load_from_csv
 from porerefiner.protocols.porerefiner.rpc.porerefiner_pb2 import RunRequest, RunListRequest, RunAttachRequest, RunRsyncRequest
 
 from asyncio import run
