@@ -144,8 +144,8 @@ async def end_file(file):
 class PoreRefinerFSEventHandler(AIOEventHandler):
     "Eventhandler for file system events via Hachiko/Watchdog"
 
-    def __init__(self, path):
-        super().__init__()
+    def __init__(self, path, *a, **k):
+        super().__init__(*a, **k)
         self.path = path
 
 
@@ -192,9 +192,9 @@ class PoreRefinerFSEventHandler(AIOEventHandler):
                         run.tag(st)
                         run.tag(dev_id)
                         run.tag(prot_id)
-                        run.save()
                     except ValueError:
                         pass
+                    run.save()
             if len(rel.parts) >=4 and not event.is_directory: #there's a file
                 log.critical(f"Registering new file {path} in {run.name}")
                 f = File.create(run=run, path=path)
@@ -207,7 +207,9 @@ class PoreRefinerFSEventHandler(AIOEventHandler):
     async def on_modified(self, event):
         if not event.is_directory: #we don't care about directory modifications
             fi = File.get_or_none(File.path == r(event.src_path))
-            if fi:
+            if not fi:
+                await self.on_created(event)
+            else:
                 fi.last_modified = datetime.now()
                 fi.save()
 
@@ -219,11 +221,11 @@ class PoreRefinerFSEventHandler(AIOEventHandler):
     #         File.delete().where(File.path == r(event.src_path)).execute()
 
 
-async def start_fs_watchdog(path, *a, **k):
+async def start_fs_watchdog(path, api=None, *a, **k):
     "Coroutine to bring up the filesystem watchdog"
     watcher = AIOWatchdog(
         path,
-        event_handler=PoreRefinerFSEventHandler(path)
+        event_handler=PoreRefinerFSEventHandler(path, *a, **k)
         )
     watcher.start()
     log.critical(f"Filesystem events being watched in {path}...")
