@@ -7,7 +7,7 @@ from pathlib import Path
 import logging
 import pkgutil
 
-
+from porerefiner.cli_utils import render_dataclass, Email, Url, PathStr
 
 SUBMITTERS = [] # configured (reified) submitters
 
@@ -109,3 +109,8 @@ class Submitter(metaclass=RegisteringABCMeta):
     def closeout_job(self, job, datadir, remotedir) -> None:
         pass
 
+    @classmethod
+    def get_configurable_options(cls):
+        "Enumerate configurable options and value type as a guide to configuration."
+        return render_dataclass(cls)
+
